@@ -69,7 +69,10 @@ class BOMInput(ModelSQL, ModelView):
     unit_digits = fields.Function(fields.Integer('Unit Digits'),
         'on_change_with_unit_digits')
     quantity = fields.Float('Quantity', required=True,
-        domain=[('quantity', '>=', 0)],
+        domain=['OR',
+            ('quantity', '>=', 0),
+            ('quantity', '=', None),
+            ],
         digits=(16, Eval('unit_digits', 2)),
         depends=['unit_digits'])
 
@@ -121,7 +124,7 @@ class BOMInput(ModelSQL, ModelView):
         self.product.check_bom_recursion()
 
     def compute_quantity(self, factor):
-        return self.uom.round(self.quantity * factor)
+        return self.uom.ceil(self.quantity * factor)
 
 
 class BOMOutput(BOMInput):
@@ -129,6 +132,9 @@ class BOMOutput(BOMInput):
     __name__ = 'production.bom.output'
     _table = 'production_bom_output'  # Needed to override BOMInput._table
 
+    def compute_quantity(self, factor):
+        return self.uom.floor(self.quantity * factor)
+
     @classmethod
     def delete(cls, outputs):
         pool = Pool()
